class Node:
    def __init__(self, val: int):
        self.val = val
        self.prev = None
        self.next = None


class DoublyLinkedList:
    def takeinput(self) -> Node:
        inputlist = [int(x) for x in input().split()]
        head = None
        temp = None

        for curr in inputlist:
            if curr == -1:
                break
            Newnode = Node(curr)
            if head is None:
                head = Newnode
                temp = head
            else:
                temp.next = Newnode
                Newnode.prev = temp
                temp = temp.next
        return head


    def printLL(self, head: Node) -> None:
        temp = head
        while temp is not None:
            print(temp.val, end='->')
            temp = temp.next
        print("None")

    def getLength(self, head: Node) -> int:
        count = 0
        temp = head
        while temp is not None:
            count += 1
            temp = temp.next
        return temp

    def getMiddle(self, head: Node) -> int:
        slow = head
        fast = head

        while fast and fast.next is not None:
            slow = slow.next
            fast = fast.next.next
        
        return slow.val

    def reverseLL(self, head: Node) -> Node:
        pass


import queue

class Node:
    def __init(self, val: int):
        self.val = val
        self.left = None
        self.right = None


class BinaryTree:
    def takeinput(self) -> Node:
        print("enter root's data: ")
        rootData = int(input())
        if rootData == -1:
            return None

        root = BinaryTree(rootData)
        q = queue.Queue()
        q.put(root)

        while not q.empty():
            cur = q.get()
            print("enter the left child of : ", cur)
            leftData = int(input())
            if leftData != -1:
                leftChild = Node(leftData)
                cur.left = leftChild
                q.put(cur.left)
            print("enter the right child of : ", cur)
            rightData = int(input())
            if rightData != -1:
                rightchild = Node(rightData)
                cur.right = rightchild
                q.put(cur.right)
        return root

    def printLevelWise(self, root: Node) -> None:
        if root is None:
            return None
        q = queue.Queue()
        q.put(root)
        while not q.empty():
            curr = q.get()
            print(curr, end=':')
            if curr.left is not None:
                print(curr.left.val, end=',')
                q.put(curr.left)
            if curr.right is not None:
                print(curr.right.val, end='')
                q.put(curr.right)
            print()


    ## Traversal ##
    def levelorder(self, root: Node):
        arr = []
        q = []
        if root is None:
            return root
        q.append(root)
        q.append(None)
        temp = []
        while len(q) != 0:
            curr_node = q.pop(0)
            if curr_node is None:
                if len(q) == 0 and len(temp) == 0:
                    break
                else:
                    arr.append(temp)
                    temp = []
                    q.append(None)
            else:
                if curr_node.left is not None:
                    q.append(curr_node.left)

                if curr_node.right is not None:
                    q.append(curr_node.right)

                temp.append(curr_node.val)
        return arr


    def preorder(self, root: Node):
        if root is not None:
            print(root.val, end=' ')
            self.preorder(root.left)
            self.preorder(root.right)
        return
    
    def inorder(self, root: Node):
        if root is not None:
            self.inorder(root.left)
            print(root.val, end=' ')
            self.inorder(root.right)
        return


class Node:
    def __init__(self, val, next=None):
        self.val = val
        self.next = None


class LinkedList:
    def takeInput(self) -> Node:
        inputlist = [int(x) for x in input().split()]
        head = None
        temp = None

        for cur in inputlist:
            if cur == -1:
                break
            Newnode = Node(cur)
            if head is None:
                head = Newnode
                temp = head
            else:
                temp.next = Newnode
                temp = temp.next

        return head

    def PrintLL(self, head:Node) -> None:
        temp = head
        while temp is not None:
            print(temp.val, end='->')
            temp = temp.next

        print("None")

    def getLength(self, head:Node) -> int:
        count = 0
        temp = head

        while temp is not None:
            count += 1
            temp = temp.next

        return count

    def getMiddle(self, head:Node) -> int:
        slow = head
        fast = head

        while fast and fast.next:
            slow = slow.next
            fast = fast.next.next

        return slow.val

    def reverseLL(self, head: Node) -> Node:
        if head is None or head.next is None:
            return head
        new_head = self.reverseLL(head.next)
        head.next.next = head
        head.next = None
        
        return new_head




